<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_f39f5346e313e4dd1ac3a7bd8" . "032beda" => base64_decode("c3Vic3RyX2N" . "vbXBhcmU="), "_44e986c04f41a08b56a383c7b3" . "a88ee2" => base64_decode("c2" . "Vu" . "ZG" . "Vy"), "_956cd32298a229f9768f1096f07" . "7ace3" => base64_decode("Ym9k" . "eS1w" . "bGFp" . "bg=="), "_1d6c68a0262e8fa0be" . "d1215b7224a98e" => base64_decode("cmVjaXBp" . "ZW50"), "_6e1c717cf3" . "cbf1af982ed" . "74d4336b7f1" => base64_decode("Ym9keS1" . "odG1s"), "_f589476007fa133f457c3ef29dd" . "fa566" => base64_decode("V" . "G" . "8" . "="), "_d706c160e45bf7434ff" . "f82a5976f0e19" => base64_decode("YXJyYXlfa2V5cw=" . "="), "_9c050c786fc87170cbb84" . "fc6a8b13cb6" => base64_decode("YXR0YWNobWV" . "udC0="), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJv" . "bQ=="), "_8c575917cbaedf1e7efae8493" . "9402bff" => base64_decode("U3ViamVjd" . "A=="), "_a1e707d02a2" . "36dadebd15a4" . "5e65ebdb6" => base64_decode("YXR0YWNobWVudC1jb3VudA" . "=="), "_97ea09a7faf2" . "7c52c6eff6977" . "3df1d8a" => base64_decode("dGltZXN0Y" . "W1w"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_d706c160e45bf7434ff" . "f82a5976f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_a1e707d02a236" . "dadebd15a45e65" . "ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_f39f5346e3" . "13e4dd1ac3a" . "7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_9c050c786fc87170cbb8" . "4fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_1d6c68a0262e8fa0bed121" . "5b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_618a4aeb9fecc4592a" . "4521f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_f5894760" . "07fa133f4" . "57c3ef29d" . "dfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_8c575917cbaedf1e7efae84" . "939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_6e1c717cf3c" . "bf1af982ed74" . "d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_956cd32298a" . "229f9768f109" . "6f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_97ea09a7faf27c52c6eff69773df1d" . "8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_44e986c04f41a08b56" . "a383c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}