<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("proj" . "ect_" . "id" => base64_decode("cHJvamVj" . "dF9pZA=="), "_bfda889b74ea561b14325e30" . "e7d75426" => base64_decode("Ym9k" . "eV9o" . "dG1s"), "_618a4aeb9fecc45" . "92a4521f34876fa2" . "9" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_c35473364fa" . "7a050299058f" . "332ec29c1" => base64_decode("ZXhjZXB" . "0aW9u"), "_f656816961e8573806141c558b184fe" . "2" => base64_decode("c3Via" . "mVjdA" . "=="), "_a3d82c5df38e1" . "94c9c73e3ccb42" . "23bbc" => base64_decode("ZW1haWxfZGF" . "0YQ=="), "_e608e5b5c4c34a6" . "7ba97ef84c1e1619" . "9" => base64_decode("J" . "w" . "=" . "="), "_5d40a2cf" . "1c525fb25" . "2bf5599e3" . "39fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbW" . "FpbDsgc3ViamVjdCAn"), "_ced92d7b391285c8a26846f" . "1f4bd3128" => base64_decode("Ym9keV90" . "ZXh0"), "_460e1aeb3113a1676ce59a" . "8f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb" . "2Nlc3MgZW1haWwgZm" . "9yIGluZm9jYXB0dXJ" . "lIHByb2plY3Q="), "_67a0d624aebcceb0abd5ce56a" . "53ff06f" => base64_decode("ZGF0ZQ" . "=="), "_376d30c40" . "857357a4d4" . "cbb1ffaa25" . "817" => base64_decode("dG8" . "="), "_03b1f0cee835582d1158dce2678b" . "505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJzY3Jp" . "YmVy"), "_9b16fa2683095e67d7c8b265" . "a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZWNlaXZlc" . "g=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_9b16fa268" . "3095e67d7c" . "8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_03b1f0cee8355" . "82d1158dce2678" . "b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_5d40a2cf1c525fb" . "252bf5599e339fdd" . "0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_e608e5b5c4c34" . "a67ba97ef84c1e" . "16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_618a4aeb9fecc" . "4592a4521f3487" . "6fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_376d30c40857357a4d4cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_f656816961e8573806141c558b184fe" . "2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_ced92d7b39" . "1285c8a2684" . "6f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_bfda889b" . "74ea561b1" . "4325e30e7" . "d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_67a0d624aebcceb0abd5ce56" . "a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_460e1aeb3113a167" . "6ce59a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["projec" . "t_id"] => $project->GetId(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_a3d82c5df38e194c9c73e3" . "ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_c35473364fa7a050299058f332ec29" . "c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}